class BigCardinal { // eigentlich public

	private String value; // repraesentiert den Wert der natuerlichen Zahl

	// Default-Konstruktor
	public BigCardinal() {
		this(0);
	}

	// Vorraussetzung: val muss >= 0 sein!
	public BigCardinal(int val) {
		this.value = "" + val;
	}

	// Voraussetzung: valueStr muss eine gueltige natuerliche Zahl
	// repraesentieren
	public BigCardinal(String valueStr) {
		this.value = valueStr;
	}

	public BigCardinal(BigCardinal obj) {
		this.value = new String(obj.value);
	}

	public String makeString() {
		return this.value;
	}

	public BigCardinal add(BigCardinal obj) {
		int maxLength = this.value.length() > obj.value.length() ? this.value
				.length() : obj.value.length();

		String newValue = "";
		int uebertrag = 0;
		for (int i = 0; i < maxLength; i++) {
			int digit1 = this.getValue(this.value.length() - 1 - i);
			int digit2 = obj.getValue(obj.value.length() - 1 - i);
			int digit3 = (digit1 + digit2 + uebertrag) % 10;
			newValue = ("" + digit3).concat(newValue);
			uebertrag = (digit1 + digit2 + uebertrag) / 10;
		}
		if (uebertrag == 1) {
			newValue = "1".concat(newValue);
		}

		this.value = newValue;
		return this;
	}

	// Voraussetzung: die Subtraktion darf keinen negativen Wert ergeben!
	public BigCardinal sub(BigCardinal obj) {
		if (this.compareTo(obj) == -1) {
			throw new ArithmeticException(); // nicht gerfordert
		}

		int maxLength = this.value.length() > obj.value.length() ? this.value
				.length() : obj.value.length();

		String newValue = "";
		int uebertrag = 0;
		for (int i = 0; i < maxLength; i++) {
			int digit1 = this.getValue(this.value.length() - 1 - i);
			int digit2 = obj.getValue(obj.value.length() - 1 - i);
			int digit3 = 0;
			if (digit1 < digit2 + uebertrag) {
				digit3 = 10 + digit1 - (digit2 + uebertrag);
				uebertrag = 1;
			} else {
				digit3 = digit1 - (digit2 + uebertrag);
				uebertrag = 0;
			}
			newValue = ("" + digit3).concat(newValue);
		}

		this.value = BigCardinal.destroyLeadingNulls(newValue);
		return this;
	}

	public int compareTo(BigCardinal obj) {
		if (this.value.length() > obj.value.length()) {
			return 1;
		}
		if (this.value.length() < obj.value.length()) {
			return -1;
		}
		for (int i = 0; i < this.value.length(); i++) {
			int digit1 = this.value.charAt(i);
			int digit2 = obj.value.charAt(i);
			if (digit1 > digit2) {
				return 1;
			}
			if (digit1 < digit2) {
				return -1;
			}
		}
		return 0;
	}

	// interne Methoden

	private int getValue(int pos) {
		return pos < 0 ? 0 : this.value.charAt(pos) - '0';
	}

	private static String destroyLeadingNulls(String str) {
		while (true) {
			if (str.equals("")) {
				return "0";
			} else if (str.charAt(0) == '0') {
				str = str.substring(1);
			} else {
				return str;
			}
		}
	}

}

public class UE15Aufgabe11 {

	// Testprogramm (nur ein Ausschnitt)
	public static void main(String[] args) {

		if (args.length < 3) {
			System.out.println("Fehlende Parameter!");
			return;
		}

		BigCardinal n1 = new BigCardinal(args[0]);
		BigCardinal n2 = new BigCardinal(args[1]);
		String op = args[2];
		System.out.println(n1.makeString() + " comp " + n2.makeString() + " = "
				+ n1.compareTo(n2));
		if (op.equals("+")) {
			System.out.println(n1.makeString() + "+" + n2.makeString() + "="
					+ n1.add(n2).makeString());
		} else {
			System.out.println(n1.makeString() + "-" + n2.makeString() + "="
					+ n1.sub(n2).makeString());
		}

	}

}
